@@ -57,11 +57,11 @@ Target::~Target()
 
 void Target::freeResources()
 {
-	//qDebug () << " free resources for " << this->id;
-	if(picture) delete picture;
-	if(pictureBack) delete pictureBack;
-	picture = NULL;
-	pictureBack = NULL;
+    qDebug () << " free resources for " << this->id;
+    if(picture) delete picture;
+    if(pictureBack) delete pictureBack;
+    picture = NULL;
+    pictureBack = NULL;
 }
 
 //bool operator<(const Entry &entry, const QString &family)
@@ -74,7 +74,7 @@ void Target::freeResources()
 
 void Target::freeFieldList()
 {
-	//qDebug () << " free list for " << this->id;
+    qDebug () << " free list for " << this->id;
 	TargetField * field;
 	foreach(field,this->fields) {
 		delete field;
@@ -549,15 +549,20 @@ bool DatabaseManager::_mergeDB (DatabaseManager * mergeDB) {
                 }
 
                 target->freeFieldList();
-                target->freeResources();
+
+                target->picture = NULL;
+                target->pictureBack = NULL;
+                target->freeResources(); // not needed it will be release by targetMerge->freeResources();
 
                 targetMerge->freeFieldList();
                 targetMerge->freeResources();
                 break;
             }
         }
+
         if (j > listMerge.size ()) {
             // NOT FOUND
+            qDebug () << "New target on merged [" << target->id << "]";
 
             this->getFields(target);
             target->getPicture(this);
@@ -571,6 +576,8 @@ bool DatabaseManager::_mergeDB (DatabaseManager * mergeDB) {
             target->freeResources();
         }
         else {
+            qDebug () << "remaining " << listMerge.size () << " elements on merge list";
+
             Target * targetMerge = listMerge[j];
             listMerge.removeAt(j);
             delete targetMerge;
@@ -776,9 +783,9 @@ QString DatabaseManager::mergeDB (const QString & dbToMerge, const QString & pas
 
         ret = mergeDB->_openFileDB(dbToMerge, "MERGE");
         if (ret) {
-            int currentVersionToMerge =  mergeDB->getVersion ();
-            if (currentVersionToMerge != SOFT_VERSION) {
-                qDebug () << "INVALID VERSION " << currentVersionToMerge;
+            mergeDB->currentVersion =  mergeDB->getVersion ();
+            if (mergeDB->currentVersion != SOFT_VERSION) {
+                qDebug () << "INVALID VERSION " << mergeDB->currentVersion;
             }
             else {
                 if (hasSecretPhrase()) {
@@ -1612,7 +1619,7 @@ bool DatabaseManager::_deleteTarget(int idTarget)
 
 bool DatabaseManager::updateFields(Target* target)
 {
-	qDebug () << "updating fields " << target->name << " " << target->fields.size();
+        qDebug () << "updating fields " << target->name << " " << target->fields.size() << " with version "<< currentVersion;
 	bool ret = false;
 	if (db.isOpen()) {
 		if (currentVersion <= 3) {
@@ -2393,3 +2400,29 @@ bool DatabaseManager::migrateTo4 () {
 
 	return ret;
 }
+
+QPixmap DatabaseManager::getImage(Target * target) {
+	QPixmap image;
+	if (target == NULL) {
+		image = QPixmap(":/resources/loading.png");
+	}
+	else
+	if (target->getPictureSmall() != NULL) {
+		image = QPixmap::fromImage(*target->getPictureSmall());
+
+		// at this moment we don't need anymore original images!
+		target->freeResources();
+	} else {
+		QString tmp = ":/resources/empty_";
+		tmp += target->type.simplified().replace(' ', '_');
+		tmp += ".png";
+
+		if (QResource(tmp).isValid()) {
+			image = QPixmap(tmp);
+		} else {
+			image = QPixmap(":/resources/empty_Others.png");
+		}
+	}
+	return image;
+}
+
