@@ -379,16 +379,17 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 #ifdef Q_WS_MAEMO_5
 	if (edit) {
+		POS = vboxlayout->count();
 		vboxlayout->addLayout(componentLayout);
 		componentLayout = new QGridLayout ();
-		//componentLayout->setSpacing(5);
 	}
 #else
+	POS = vboxlayout->count();
 	vboxlayout->addLayout(componentLayout);
 	componentLayout = new QGridLayout ();
 #endif
 
-	showFields ();
+	showFields (true);
 
 	vboxlayout->addLayout(componentLayout);
 
@@ -438,7 +439,7 @@ void DetailWindow::modifyFields() {
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
 		if (createFieldDlg->exec() == QDialog::Accepted) {
 			// TODO sort fields!!!
-			showFields ();
+			showFields (false);
 		}
 
 		delete createFieldDlg;
@@ -488,6 +489,7 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
+
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 #else
@@ -495,15 +497,21 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setText (field->value);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
-		QHBoxLayout * ll = new QHBoxLayout;
+
+		QWidget *window = new QWidget (this);
+		window->setContentsMargins(0, 0, 0, 0);
+		QHBoxLayout * ll = new QHBoxLayout (window);
+		ll->setContentsMargins(0, 0, 0, 0);
 		ll->addWidget(nameLineEdit);
-		QPushButton * generate = new QPushButton(tr("Generate"), this);
+		QPushButton * generate = new QPushButton(tr("Generate"), window);
 		ll->addWidget(generate);
 		generate->setUserData(0, new ButtonInfo2 (nameLineEdit)); //ObjectName(field->value);
 		signalMapper->setMapping(generate, generate);
 		QObject::connect(generate, SIGNAL(clicked()), signalMapper, SLOT(map()));
+		window->setLayout(ll);
+		this->others.append(window);
 
-		componentLayout->addLayout(ll, pos, 1, 1, 1);
+		componentLayout->addWidget(window, pos, 1, 1, 1);
 		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 #endif
 	}
@@ -581,21 +589,50 @@ void DetailWindow::_addField (TargetField * field) {
 	////qDebug () << "SHOWN " << field->name << " v=" << field->value << " t=" << field->type;
 }
 
-void DetailWindow::showFields () {
+void DetailWindow::showFields (bool firstTime) {
 
 	if (edit) {
-		for (int i = 0; i < this->labels.size(); i++) {
-			componentLayout->removeWidget(this->labels[i]);
-			delete this->labels[i];
+		if (!firstTime) {
+//			QObjectList list = componentLayout->children();
+//			for (int u = 0, N = list.size(); u < N; u++) {
+//				componentLayout->removeWidget(list.)
+//			}
+
+			for (int i = 0; i < this->labels.size(); i++) {
+				componentLayout->removeWidget(this->labels[i]);
+				delete this->labels[i];
+			}
+
+			for (int i = 0; i < this->values.size(); i++) {
+				componentLayout->removeWidget(this->values[i]);
+				delete this->values[i];
+			}
+
+			for (int i = 0; i < this->others.size(); i++) {
+				componentLayout->removeWidget(this->others[i]);
+				delete this->others[i];
+			}
+
+//#ifdef Q_WS_MAEMO_5
+        vboxlayout->removeItem(componentLayout);
+        delete componentLayout;
+        componentLayout = new QGridLayout ();
+        vboxlayout->insertLayout(POS + 1, componentLayout);
+//#else
+//        int ii = vboxlayout->indexOf(componentLayout);
+//        vboxlayout->removeItem(componentLayout);
+//        delete componentLayout;
+//        componentLayout = new QGridLayout ();
+//        vboxlayout->insertLayout(ii, componentLayout);
+//#endif
 		}
 
-		for (int i = 0; i < this->values.size(); i++) {
-			componentLayout->removeWidget(this->values[i]);
-			delete this->values[i];
-		}
+//
+//		componentLayout->update();
 
 		this->values.clear();
 		this->labels.clear();
+		this->others.clear();
 	}
 
 	signalMapper = new QSignalMapper(this);
@@ -675,17 +712,6 @@ void DetailWindow::showFields () {
 
 							componentLayout->addWidget(imageLabel, pos, 1, 1, 1);
 							imageLabel->setPicture(field);
-
-							//setContextMenuPolicy(Qt::CustomContextMenu);
-							//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(labelMenu(const QPoint&)));
-//
-//							if (isImage) {
-//								this->setBackgroundRole(QPalette::NoRole);
-//								//this->setContentsMargins(5, 2, 0, 2);
-//								this->setMaximumSize(OTHER_WIDTH, OTHER_HEIGH);
-//								//this->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
-//								this->setScaledContents(true);
-
 						}
 						else {
 							QLabel * nameLineEdit = new QLabelW(field->value, false, false, false, this);
@@ -773,7 +799,7 @@ void DetailWindow::changeFields (int a) {
 
 void DetailWindow::emitCommitData (int a) {
 	changeFields (a);
-	showFields();
+	showFields(false);
 }
 
 DetailWindow::~DetailWindow () {
