@@ -46,6 +46,7 @@ private:
 	QComboBox * typeLineEdit;
 	QList<QLineEdit*> labels;
 	QList<QWidget*> values;
+	QList<QWidget*> others;
 
 	QPointer <QMessageBox> messageBox;
 
@@ -56,7 +57,7 @@ private:
 
 	QString orgType;
 
-	void showFields ();
+	void showFields (bool firsTime);
 	void changeFields (int);
 	void _addField (TargetField * field);
 
@@ -73,6 +74,8 @@ private:
 	QSignalMapper * signalMapper;
 	QPointer<CreatePasswordDialog> createPasswordDlg;
 
+	int POS;
+
 public slots:
 	void saveTarget();
 	void _deleteTarget();
