@@ -18,26 +18,27 @@
 #include "DetailedWindow.h"
 #include "LoginDialog.h"
 #include "EditTemplates.h"
+#include "ListOfCards.h"
 
 extern DatabaseManager * dbManager;
 
-class MyLoadImageThread: public QThread {
-	Q_OBJECT
-
-	signals:
-		void loadImageFor (int index);
-	public:
-		int size;
-
-		void run() {
-			qDebug () << "loading images START";
-			for (int i = 0; i < size; i++) {
-				qDebug () << "loading image " << i;
-				emit loadImageFor(i);
-			}
-			qDebug () << "loading images FINISH";
-		}
-};
+//class MyLoadImageThread: public QThread {
+//	Q_OBJECT
+//
+//	signals:
+//		void loadImageFor (int index);
+//	public:
+//		int size;
+//
+//		void run() {
+//			qDebug () << "loading images START";
+//			for (int i = 0; i < size; i++) {
+//				qDebug () << "loading image " << i;
+//				emit loadImageFor(i);
+//			}
+//			qDebug () << "loading images FINISH";
+//		}
+//};
 
 class eWallet: public QMainWindow
 {
@@ -51,8 +52,7 @@ public:
 
 	static void preProcessImage (QImage * image);
 
-	bool _deleteTarget(Target* target);
-	bool _updateTarget(Target* target);
+	bool _updateTarget(Target* t);
 	bool _updateTargetPicture(Target* target);
 	bool _updateTargetPictureBack(Target* target);
 	bool _insertTarget(Target* target);
@@ -65,25 +65,17 @@ public:
 	void hideN ();
 
 public slots:
-	void newTarget();
-	void editTarget(Target * t);
-	void deleteTarget(Target * t);
-	void viewTarget(Target * t);
 	Q_SCRIPTABLE void listenInactivity(QString s);
-
-	void selectItem(QListWidgetItem *);
-	void selectDItem(QListWidgetItem *);
-
+	bool deleteTarget(Target * t);
 	void deleteDB ();
-	void changeMode ();
 
 private:
-	class MyDelegate;
+//	class MyDelegate;
 
-	QPointer<MyLoadImageThread> threadLoad;
+	//QPointer<MyLoadImageThread> threadLoad;
 
-	QAbstractItemDelegate * originalDelegate;
-	QAbstractItemDelegate * newDelegate;
+//	QAbstractItemDelegate * originalDelegate;
+//	QAbstractItemDelegate * newDelegate;
 
 	void initTemplates ();
 
@@ -91,15 +83,15 @@ private:
 	void showList (bool interactive);
 	void keyPressEvent(QKeyEvent*);
 	void createMenu();
-	void showGroups(bool reset);
+	//void showGroups(bool reset);
 	void showInfo(bool reset);
-	void showTargets(bool reset, const QString * filter);
+	//void showTargets(bool reset, const QString * filter);
 
 	void loadTypesAndFields ();
 	void _loadTypesAndFields (QList<Target*> * types); //, QList<QList<TargetField*>*> * fieldsByType);
 
-	void filterBy (const QString & s);
-	QPixmap getImage (Target * f);
+	//void filterBy (const QString & s);
+	//QPixmap getImage (Target * f);
 
 	bool isAskPassword;
 	bool isChangingPassword;
@@ -107,7 +99,7 @@ private:
     void reallyChangePassword (const QString & newPassword);
 
 private slots:
-	void loadImageFor (int index);
+	void viewGroup(QString * _target);
 
 	void finalPassword (const QString pas);
 	void finalChangePassword (const QString pas);
@@ -122,22 +114,26 @@ private slots:
 
     void editTemplates();
 
-    void sort ();
     void changePassword ();
 
-    void _newLikeTarget ();
-    void _duplicateTarget ();
+	void _editTarget();
+    void _sort ();
+//    void _newLikeTarget ();
+//    void _duplicateTarget ();
 
     void newLikeTarget (Target * );
     void duplicateTarget (Target * );
+	void newTarget();
+	void editTarget(Target * t);
+	void viewTarget(Target * t);
 
-	void _editcTarget();
-	void _clickBack();
-	void _deletecTarget();
-	void _viewcTarget();
+//	void _editcTarget();
+////	void _clickBack();
+//	void _deletecTarget();
+//	void _viewcTarget();
 	void lockWallet ();
-	void _cancelSearch ();
-	void _hideSearch ();
+//	void _cancelSearch ();
+//	void _hideSearch ();
 	void about ();
 	void options ();
 	void optionsAntiTheft ();
@@ -146,10 +142,10 @@ private slots:
 	void exportXml();
 	void importXml();
 	void mergeDB();
-	void textChanged (const QString &);
-	void contextMenuEvent (QContextMenuEvent * event);
-	void renameGroup ();
-	void deleteGroup ();
+	//void textChanged (const QString &);
+	//void contextMenuEvent (QContextMenuEvent * event);
+	void renameGroup (QString n);
+	bool deleteGroup (QString n);
 
 	void createDatabase ();
 	void migrateDatabase (int from, int to);
@@ -164,16 +160,16 @@ private:
 	void closeEvent(QCloseEvent *event);
 	bool isFirst;
 	bool isUnLockMode;
-	QVBoxLayout * vboxlayout;
+//	QVBoxLayout * vboxlayout;
 	int times;
-	QListWidget* fnListWidget;
-	QList<Target *> list;
-	QList<QString> grouplist;
+//	QListWidget* fnListWidget;
+//	QList<Target *> list;
+//	QList<QString> grouplist;
 
-	QHBoxLayout * inputWidget;
-	QPushButton * cancelSearch;
-	QPushButton * hideSearch;
-	QLineEdit * searchField;
+//	QHBoxLayout * inputWidget;
+//	QPushButton * cancelSearch;
+//	QPushButton * hideSearch;
+//	QLineEdit * searchField;
 	//QPushButton * backButton;
 
 	QPointer<EditTemplates> templatesWindow;
@@ -181,13 +177,13 @@ private:
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
 	QPointer<eWallet> extraWindow;
-	QWidget* centralWidget;
+	ListOfCards * centralWidget;
 	QPointer <QMessageBox> messageBox;
 	bool opendb;
 	bool initdb;
-	bool ascSort;
+	//bool ascSort;
 	int isShowGroups;
-	QString currentFilter;
+//	QString currentFilter;
 	QString * currentGroup;
 
 	QString tempPass;
